.reading-time-panel {

}
.reading-time-panel-data .loading.loading::after {
    top: 0;
    left: 0;
    transform: translateY(-50%);
}
.reading-time-panel-data svg {
    width: 1em;
    height: 1em;
    cursor: pointer;
    margin-right: 0.5em;
    vertical-align: middle;
}